# EventorPy

Eventorpy is a python library that makes it easier to use eventors api's.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install.

```bash
pip install eventorpy
```

## Usage

```python
import eventorpy

```

## License

[MIT](https://choosealicense.com/licenses/mit/)